Structs
- Trunk
Install - TrunkInstall : TrunkInstall allows installation of extensions from the pgtrunk registry. This list should be a list of extension names and versions that you wish to install at runtime using the pgtrunk API. This example will install the pg_stat_statements extension at version 1.10.0.
yaml apiVersion: coredb.io/v1alpha1 kind: CoreDB metadata: name: test-db spec: trunk_installs: - name: pg_stat_statements version: 1.10.0